package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.QmsFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:09
 */
@RestController
@RequestMapping("${api.version}/qms")
public class QMSController extends BaseRESTfulController {

    @Autowired
    private QmsFeign qmsFeign;

    @ApiOperation(value="触发电子围栏-->新增排队实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/addQueueResult")
    public Map<String, Object> addQueueResult(String vno){
        return qmsFeign.addQueueResult(vno);
    }

    @ApiOperation(value="指令接收-->新增排队链表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/addQueueList")
    public Map<String, Object> addQueueList(String resultId){
        return qmsFeign.addQueueList(resultId);
    }

    @ApiOperation(value="指令接收")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(130)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/orderReceive")
    public Map<String, Object> orderReceive(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer queueType,
                                            String con
    ){
        return qmsFeign.orderReceive(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, queueType,con);
    }


    @ApiOperation(value="查询排队申请")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(125)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueApply")
    public Map<String, Object> getQueueApply(@RequestBody(required=false) Map<String,Object> mapValue,
                                             Integer apiId,
                                             Integer pageNum,
                                             Integer pageSize,
                                             String con
    ){
        return qmsFeign.getQueueApply(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,con);
    }


    @ApiOperation(value="查询排队开始")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(128)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueListByQueueUp")
    public Map<String, Object> getQueueListByQueueUp(@RequestBody(required=false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer locationId,
                                                     String capacityNumber,
                                                     Integer isSpelling
    ){
        return qmsFeign.getQueueListByQueueUp(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, locationId,capacityNumber, isSpelling);
    }

    @ApiOperation(value="查询排队转移")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(124)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getChangeQueue")
    public Map<String, Object> getChangeQueue(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String con
    ){
        return qmsFeign.getChangeQueue(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize,con);
    }

    @ApiOperation(value="查询排队取消")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(131)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueCancel")
    public Map<String, Object> getQueueCancel(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String con
    ){
        return qmsFeign.getQueueCancel(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,con);
    }

    @ApiOperation(value="修改排队取消实绩：时间、原因")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
    })
    @PostMapping("/updateQueueCancel")
    public Map<String, Object> updateQueueCancel(@RequestBody(required=false) Map<String,Object> mapValue){
        return qmsFeign.updateQueueCancel(mapValue);
    }

    @ApiOperation(value="排队取消-->修改排队链表deleted为1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/queueCancel")
    public Map<String, Object> queueCancel(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsFeign.queueCancel(mapValue);
    }


    @ApiOperation(value="排队插队-->修改排队链表顺序号为最小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/queueCutInLine")
    public Map<String, Object> queueCutInLine(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsFeign.queueCutInLine(mapValue);
    }


    @ApiOperation(value="查询排队插队")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(132)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueInsert")
    public Map<String, Object> getQueueInsert(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              String con
    ){
        return qmsFeign.getQueueInsert(mapValue == null?new HashMap<>():mapValue, apiId, pageNum, pageSize,con);
    }

    @ApiOperation(value="查询排队结束")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(133)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getQueueEndResult")
    public Map<String, Object> getQueueEndResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                 Integer apiId,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 String con
    ){
        return qmsFeign.getQueueEndResult(mapValue == null?new HashMap<>():mapValue, apiId, pageNum, pageSize,con);
    }

    @ApiOperation(value="链表监控")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(134)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/listMonitor")
    public Map<String, Object> listMonitor(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer isSpelling
    ){return qmsFeign.listMonitor(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize,isSpelling);
    }

    @ApiOperation(value="通过车牌号查询司机接单")
    @PostMapping("/getOrderReceive/{capacityNumber}")
    public Map<String, Object> getOrderReceive(@PathVariable("capacityNumber") String capacityNumber){
        return qmsFeign.getOrderReceive(capacityNumber);
    }

    @ApiOperation(value="通过车牌号取消排队")
    @PostMapping("/cancelQueue")
    public Map<String, Object> cancelQueue(@RequestBody Map<String,Object> mapValue){
        return qmsFeign.cancelQueue(mapValue);
    }

    @ApiOperation(value="钢材科允许进厂")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "网格Id", required = false, dataType = "Map"),
    })
    @PostMapping("/allowEnFactory")
    public Map<String, Object> allowEnFactory(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsFeign.allowEnFactory(mapValue);
    }

    @ApiOperation(value="APP端司机查看排队信息")
    @GetMapping("getQueueResultByTotalId")
    public Map<String, Object> getQueueResultByTotalId(String resultTotalId){
        return  qmsFeign.getQueueResultByTotalId(resultTotalId);
    }


    @ApiOperation(value="单拼链表查看详情")
    @PostMapping("/getListMonitorMes")
    public Map<String, Object> getListMonitorMes(@RequestBody(required=false) Map<String,Object> mapValue){
        return qmsFeign.getListMonitorMes(mapValue);
    }

    @ApiOperation(value="多拼链表查看详情")
    @PostMapping("/getSpellingListMonitorMes")
    public Map<String, Object> getSpellingListMonitorMes(@RequestBody(required=false) Map<String,Object> mapValue){
        return qmsFeign.getSpellingListMonitorMes(mapValue);
    }


    @ApiOperation(value="排队结束-->修改deleted = 1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/queueEndByPDA")
    public Map<String, Object> queueEnd(@RequestBody(required=false) Map<String, Object> mapValue){
        return qmsFeign.queueEnd(mapValue);
    }


//    @ApiOperation(value="查询进厂排队详情")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
//            @ApiImplicitParam(name = "apiId(184)", value = "动态表头", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
//    })
//    @PostMapping("/getAllQueueMes")
//    public Map<String, Object> getAllQueueMes(@RequestBody(required=false) Map<String,Object> mapValue,
//                                              Integer apiId,
//                                              Integer pageNum,
//                                              Integer pageSize,
//                                              Integer gatepostId,
//                                              String con
//    ){
//        return qmsFeign.getAllQueueMes(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, gatepostId,con);
//    }

//    @ApiOperation(value="排队转移-->新增排队链表:实绩Id、门岗名称、转移原因")
//    @PostMapping("/changeQueue")
//    public Map<String, Object> changeQueue(@RequestBody(required=false) Map<String, Object> mapValue){
//        return qmsFeign.changeQueue(mapValue);
//    }




//    @ApiOperation(value="通过Id查询排队取消实绩")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "", required = false, dataType = "Map"),
//    })
//    @PostMapping("/getQueueCancelByResultId/{resultId}")
//    public Map<String, Object> getQueueCancelByResultId(@PathVariable("resultId") Integer resultId){
//        return qmsFeign.getQueueCancelByResultId(resultId);
//    }



//    @ApiOperation(value="汽车监控")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
//            @ApiImplicitParam(name = "apiId(135)", value = "动态表头", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
//    })
//    @PostMapping("/capacityMonitor")
//    public Map<String, Object> capacityMonitor(@RequestBody(required=false) Map<String,Object> mapValue,
//                                               Integer apiId,
//                                               Integer pageNum,
//                                               Integer pageSize,
//                                               Integer gridType,
//                                               String con
//    ){
//        return qmsFeign.capacityMonitor(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize, gridType,con);
//    }




//    @ApiOperation(value="查询各仓库，门岗的排队状态列表")
//    @PostMapping("/getQueueStatusList")
//    public Map<String, Object> getQueueStatusList(){
//        return qmsFeign.getQueueStatusList();
//    }



//    @ApiOperation(value="查询执行中订单")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
//            @ApiImplicitParam(name = "apiId(156)", value = "动态表头", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
//    })
//    @PostMapping("/getAllExecutionOrder")
//    public Map<String, Object> getAllExecutionOrder(@RequestBody(required=false) Map<String,Object> mapValue,
//                                                    Integer apiId,
//                                                    Integer pageNum,
//                                                    Integer pageSize,
//                                                    Integer orderType,
//                                                    Integer status,
//                                                    String con
//    ){
//        return qmsFeign.getAllExecutionOrder(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, orderType, status,con);
//    }

//    @ApiOperation(value="查询某一个门岗的排队详情")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "网格Id", required = false, dataType = "Map"),
//    })
//    @PostMapping("/getListQueueMes")
//    public RESTfulResult getListQueueMes(@RequestBody(required=false) Map<String, Object> mapValue){
//        return qmsFeign.getListQueueMes(mapValue);
//    }


//    @ApiOperation(value="查询仓库排队详情")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
//            @ApiImplicitParam(name = "apiId(187)", value = "动态表头", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
//    })
//    @PostMapping("/getWarehouseQueueApply")
//    public Map<String, Object> getWarehouseQueueApply(@RequestBody(required=false) Map<String,Object> mapValue,
//                                                      Integer apiId,
//                                                      Integer pageNum,
//                                                      Integer pageSize,
//                                                      Integer platformId,
//                                                      String con
//    ){return qmsFeign.getWarehouseQueueChange(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize,con);
//    }
//    @ApiOperation(value="查询仓库排队转移")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
//            @ApiImplicitParam(name = "apiId(193)", value = "动态表头", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
//    })
//    @PostMapping("/getWarehouseQueueChange")
//    public Map<String, Object> getWarehouseQueueChange(@RequestBody(required=false) Map<String,Object> mapValue,
//                                                       Integer apiId,
//                                                       Integer pageNum,
//                                                       Integer pageSize,
//
//                                                       String con
//    ){return qmsFeign.getWarehouseQueueChange(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize,con);
//    }


//    @ApiOperation(value="查询仓库排队结束")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
//            @ApiImplicitParam(name = "apiId(194)", value = "动态表头", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
//    })
//    @PostMapping("/getWarehouseQueueEndMes")
//    public Map<String, Object> getWarehouseQueueEndMes(@RequestBody(required=false) Map<String,Object> mapValue,
//                                                       Integer apiId,
//                                                       Integer pageNum,
//                                                       Integer pageSize,
//                                                       String con
//    ){return qmsFeign.getWarehouseQueueEndMes(mapValue == null ? new HashMap<>(): mapValue, apiId, pageNum, pageSize,con);
//    }

}
